==> sddm-0.11.0.tar.gz: sddm-0.11.0/data/translations/kk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="kk">
<context>
    <name>TextConstants</name>
    <message>
        <source>Welcome to %1</source>
        <translation>%1 ішіне қош келдіңіз</translation>
    </message>
    <message>
        <source>Warning, Caps Lock is ON!</source>
        <translation>Caps Lock іске қосулы тұр!</translation>
    </message>
    <message>
        <source>Layout</source>
        <translation>Пернетақта жаймасы</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Кіру</translation>
    </message>
    <message>
        <source>Login failed</source>
        <translation>Кіру сәтсіз</translation>
    </message>
    <message>
        <source>Login succeeded</source>
        <translation>Кіру орындалды</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Пароль</translation>
    </message>
    <message>
        <source>Enter your username and password</source>
        <translation>Пайдаланушы атын және паролін енгізіңіз</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Қайта жүктеу</translation>
    </message>
    <message>
        <source>Session</source>
        <translation>Сессия</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Сөндіру</translation>
    </message>
    <message>
        <source>User name</source>
        <translation>Пайдаланушы аты</translation>
    </message>
    <message>
        <source>Select your user and enter password</source>
        <translation>Пайдаланушыны таңдап, парольді енгізіңіз</translation>
    </message>
</context>
</TS>

==> sddm_0.19.0.orig.tar.gz: sddm-0.19.0/data/translations/kk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="kk">
<context>
    <name>PictureBox</name>
    <message>
        <source>Press to login</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>%1 (Wayland)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TextConstants</name>
    <message>
        <source>Welcome to %1</source>
        <translation>%1 ішіне қош келдіңіз</translation>
    </message>
    <message>
        <source>Warning, Caps Lock is ON!</source>
        <translation>Caps Lock іске қосулы тұр!</translation>
    </message>
    <message>
        <source>Layout</source>
        <translation>Пернетақта жаймасы</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Кіру</translation>
    </message>
    <message>
        <source>Login failed</source>
        <translation>Кіру сәтсіз</translation>
    </message>
    <message>
        <source>Login succeeded</source>
        <translation>Кіру орындалды</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Пароль</translation>
    </message>
    <message>
        <source>Enter your username and password</source>
        <translation>Пайдаланушы атын және паролін енгізіңіз</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Қайта жүктеу</translation>
    </message>
    <message>
        <source>Session</source>
        <translation>Сессия</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Сөндіру</translation>
    </message>
    <message>
        <source>User name</source>
        <translation>Пайдаланушы аты</translation>
    </message>
    <message>
        <source>Select your user and enter password</source>
        <translation>Пайдаланушыны таңдап, парольді енгізіңіз</translation>
    </message>
</context>
</TS>
